==> haskell-lift-type-0.1.2.0-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-U1GoZjo4IKFUhUBKJrap6
key:                  lift-type-0.1.2.0-U1GoZjo4IKFUhUBKJrap6
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  2363b065fa7cb96c3aa10f6d1cc8e5cf
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-U1GoZjo4IKFUhUBKJrap6
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lift-type-0.1.2.0-88-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-lift-type.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lift-type
version:              0.1.2.0
visibility:           public
id:                   lift-type-0.1.2.0-BQQGrSfNZhSEyukBMwcJiO
key:                  lift-type-0.1.2.0-BQQGrSfNZhSEyukBMwcJiO
license:              BSD-3-Clause
copyright:            2021 Matt Parsons
maintainer:           parsonsmatt@gmail.com
author:               Matt Parsons
homepage:             https://github.com/parsonsmatt/lift-type#readme
synopsis:
    Lift a type from a Typeable constraint to a Template Haskell type

description:
    Lift your types from a Typeable constraint to a Template Haskell type

abi:                  166f34bf71a787213308eb6d6a78cf76
exposed:              True
exposed-modules:      LiftType
import-dirs:          /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/lift-type-0.1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lift-type
hs-libraries:         HSlift-type-0.1.2.0-BQQGrSfNZhSEyukBMwcJiO
depends:              base-4.17.2.1 template-haskell-2.19.0.0
haddock-interfaces:   /usr/share/doc/haskell-lift-type/html/lift-type.haddock
haddock-html:         /usr/share/doc/haskell-lift-type/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
